You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cxf.apache.org by bu...@apache.org on 2019/05/23 11:57:29 UTC

[cxf] branch master updated: cxf-systests-rs-security: introduce SpringBusTestServer

This is an automated email from the ASF dual-hosted git repository.

buhhunyx pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/cxf.git


The following commit(s) were added to refs/heads/master by this push:
     new c0343f1  cxf-systests-rs-security: introduce SpringBusTestServer
c0343f1 is described below

commit c0343f18c29cf41cc361d8ef7abea4c04baa4b27
Author: Alexey Markevich <bu...@gmail.com>
AuthorDate: Thu May 23 14:56:35 2019 +0300

    cxf-systests-rs-security: introduce SpringBusTestServer
---
 .../security/oauth2/common/OAuth2TestUtils.java    |   9 +-
 .../security/oidc/OIDCDynamicRegistrationTest.java |  17 ++-
 .../systest/jaxrs/security/oidc/OIDCFlowTest.java  | 143 +++------------------
 .../jaxrs/security/oidc/OIDCNegativeTest.java      | 142 +++-----------------
 ...trationServer.java => SpringBusTestServer.java} |  32 ++---
 .../systest/jaxrs/security/oidc/UserInfoTest.java  | 141 +++-----------------
 .../cxf/systest/jaxrs/security/oidc/client.xml     |  14 +-
 ...oidc-negative-server-jcache-jwt-non-persist.xml |  10 +-
 .../oidc/oidc-negative-server-jcache-jwt.xml       |  10 +-
 .../security/oidc/oidc-negative-server-jcache.xml  |  10 +-
 .../security/oidc/oidc-negative-server-jpa.xml     |  10 +-
 .../jaxrs/security/oidc/oidc-server-dynreg.xml     |   6 +-
 .../oidc/oidc-server-jcache-jwt-non-persist.xml    |   8 +-
 .../jaxrs/security/oidc/oidc-server-jcache-jwt.xml |   8 +-
 .../jaxrs/security/oidc/oidc-server-jcache.xml     |   8 +-
 .../jaxrs/security/oidc/oidc-server-jpa.xml        |   8 +-
 .../userinfo-server-jcache-jwt-non-persist.xml     |  12 +-
 .../security/oidc/userinfo-server-jcache-jwt.xml   |  12 +-
 .../jaxrs/security/oidc/userinfo-server-jcache.xml |  12 +-
 .../jaxrs/security/oidc/userinfo-server-jpa.xml    |  12 +-
 20 files changed, 156 insertions(+), 468 deletions(-)

diff --git a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oauth2/common/OAuth2TestUtils.java b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oauth2/common/OAuth2TestUtils.java
index 0d611e0..336381b 100644
--- a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oauth2/common/OAuth2TestUtils.java
+++ b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oauth2/common/OAuth2TestUtils.java
@@ -19,7 +19,7 @@
 package org.apache.cxf.systest.jaxrs.security.oauth2.common;
 
 import java.time.Instant;
-import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Properties;
@@ -164,16 +164,11 @@ public final class OAuth2TestUtils {
     }
 
     public static List<Object> setupProviders() {
-        List<Object> providers = new ArrayList<>();
         JSONProvider<OAuthAuthorizationData> jsonP = new JSONProvider<>();
         jsonP.setNamespaceMap(Collections.singletonMap("http://org.apache.cxf.rs.security.oauth",
                                                        "ns2"));
-        providers.add(jsonP);
-        providers.add(new OAuthJSONProvider());
-        providers.add(new JsonWebKeysProvider());
-        providers.add(new JsonMapObjectProvider());
 
-        return providers;
+        return Arrays.asList(jsonP, new OAuthJSONProvider(), new JsonWebKeysProvider(), new JsonMapObjectProvider());
     }
 
     public static String createToken(String audRestr) throws WSSecurityException {
diff --git a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynamicRegistrationTest.java b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynamicRegistrationTest.java
index 69c7188..d3a158e 100644
--- a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynamicRegistrationTest.java
+++ b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynamicRegistrationTest.java
@@ -40,18 +40,17 @@ import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 
 public class OIDCDynamicRegistrationTest extends AbstractBusClientServerTestBase {
-    public static final String PORT = OIDCDynRegistrationServer.PORT;
+    private static final SpringBusTestServer DYNREG_SERVER = new SpringBusTestServer("oidc-server-dynreg");
 
     @BeforeClass
     public static void startServers() throws Exception {
-        assertTrue("server did not launch correctly",
-                   launchServer(OIDCDynRegistrationServer.class, true));
+        assertTrue("server did not launch correctly", launchServer(DYNREG_SERVER));
     }
 
     @org.junit.Test
     public void testGetClientRegNotAvail() throws Exception {
         URL busFile = OIDCDynamicRegistrationTest.class.getResource("client.xml");
-        String address = "https://localhost:" + PORT + "/services/dynamic/register";
+        String address = "https://localhost:" + DYNREG_SERVER.getPort() + "/services/dynamic/register";
         WebClient wc = WebClient.create(address, Collections.singletonList(new JsonMapObjectProvider()),
                          busFile.toString());
         Response r = wc.accept("application/json").path("some-client-id").get();
@@ -60,7 +59,7 @@ public class OIDCDynamicRegistrationTest extends AbstractBusClientServerTestBase
     @org.junit.Test
     public void testRegisterClientNoInitialAccessToken() throws Exception {
         URL busFile = OIDCDynamicRegistrationTest.class.getResource("client.xml");
-        String address = "https://localhost:" + PORT + "/services/dynamic/register";
+        String address = "https://localhost:" + DYNREG_SERVER.getPort() + "/services/dynamic/register";
         WebClient wc = WebClient.create(address, Collections.singletonList(new JsonMapObjectProvider()),
                          busFile.toString());
         wc.accept("application/json").type("application/json");
@@ -71,7 +70,7 @@ public class OIDCDynamicRegistrationTest extends AbstractBusClientServerTestBase
     @org.junit.Test
     public void testRegisterClientInitialAccessTokenCodeGrant() throws Exception {
         URL busFile = OIDCDynamicRegistrationTest.class.getResource("client.xml");
-        String address = "https://localhost:" + PORT + "/services/dynamicWithAt/register";
+        String address = "https://localhost:" + DYNREG_SERVER.getPort() + "/services/dynamicWithAt/register";
         WebClient wc = WebClient.create(address, Collections.singletonList(new JsonMapObjectProvider()),
                          busFile.toString());
 
@@ -106,7 +105,7 @@ public class OIDCDynamicRegistrationTest extends AbstractBusClientServerTestBase
     @org.junit.Test
     public void testRegisterClientPasswordGrant() throws Exception {
         URL busFile = OIDCDynamicRegistrationTest.class.getResource("client.xml");
-        String address = "https://localhost:" + PORT + "/services/dynamicWithAt/register";
+        String address = "https://localhost:" + DYNREG_SERVER.getPort() + "/services/dynamicWithAt/register";
         WebClient wc = WebClient.create(address, Collections.singletonList(new JsonMapObjectProvider()),
                          busFile.toString());
 
@@ -145,7 +144,7 @@ public class OIDCDynamicRegistrationTest extends AbstractBusClientServerTestBase
     @org.junit.Test
     public void testRegisterClientPasswordGrantPublic() throws Exception {
         URL busFile = OIDCDynamicRegistrationTest.class.getResource("client.xml");
-        String address = "https://localhost:" + PORT + "/services/dynamicWithAt/register";
+        String address = "https://localhost:" + DYNREG_SERVER.getPort() + "/services/dynamicWithAt/register";
         WebClient wc = WebClient.create(address, Collections.singletonList(new JsonMapObjectProvider()),
                          busFile.toString());
 
@@ -196,7 +195,7 @@ public class OIDCDynamicRegistrationTest extends AbstractBusClientServerTestBase
     @org.junit.Test
     public void testRegisterClientInitialAccessTokenCodeGrantTls() throws Exception {
         URL busFile = OIDCDynamicRegistrationTest.class.getResource("client.xml");
-        String address = "https://localhost:" + PORT + "/services/dynamicWithAt/register";
+        String address = "https://localhost:" + DYNREG_SERVER.getPort() + "/services/dynamicWithAt/register";
         WebClient wc = WebClient.create(address, Collections.singletonList(new JsonMapObjectProvider()),
                          busFile.toString());
 
diff --git a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynRegistrationServer.java b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/SpringBusTestServer.java
similarity index 61%
rename from systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynRegistrationServer.java
rename to systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/SpringBusTestServer.java
index fec1220..2b80c6d 100644
--- a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCDynRegistrationServer.java
+++ b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/SpringBusTestServer.java
@@ -21,28 +21,28 @@ package org.apache.cxf.systest.jaxrs.security.oidc;
 
 import java.net.URL;
 
-import org.apache.cxf.Bus;
-import org.apache.cxf.BusFactory;
 import org.apache.cxf.bus.spring.SpringBusFactory;
 import org.apache.cxf.testutil.common.AbstractBusTestServerBase;
 import org.apache.cxf.testutil.common.TestUtil;
 
-public class OIDCDynRegistrationServer extends AbstractBusTestServerBase {
-    public static final String PORT = TestUtil.getPortNumber("jaxrs-oidc-dynreg");
-    private static final URL SERVER_CONFIG_FILE =
-        OIDCDynRegistrationServer.class.getResource("oidc-server-dynreg.xml");
+import static org.junit.Assert.assertNotNull;
+
+public class SpringBusTestServer extends AbstractBusTestServerBase {
+    private final String port;
+    private final URL serverConfigFile;
+
+    public SpringBusTestServer(String template) {
+        port = TestUtil.getPortNumber(template);
+        serverConfigFile = getClass().getResource(template + ".xml");
+        assertNotNull(serverConfigFile);
+    }
+
+    public String getPort() {
+        return port;
+    }
 
     protected void run() {
-        SpringBusFactory bf = new SpringBusFactory();
-        Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-        BusFactory.setDefaultBus(springBus);
-        setBus(springBus);
-
-        try {
-            new OIDCDynRegistrationServer();
-        } catch (Exception e) {
-            throw new RuntimeException(e);
-        }
+        setBus(new SpringBusFactory().createBus(serverConfigFile));
     }
 
 }
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/client.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/client.xml
index 1663654..b90f73d 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/client.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/client.xml
@@ -18,14 +18,16 @@
  under the License.
 -->
 <beans xmlns="http://www.springframework.org/schema/beans"
-    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xmlns:http="http://cxf.apache.org/transports/http/configuration"
-    xmlns:jaxws="http://cxf.apache.org/jaxws"
     xmlns:cxf="http://cxf.apache.org/core"
-    xmlns:p="http://cxf.apache.org/policy"
     xmlns:sec="http://cxf.apache.org/configuration/security"
-    xsi:schemaLocation="http://www.springframework.org/schema/beans http://www.springframework.org/schema/beans/spring-beans.xsd http://cxf.apache.org/jaxws http://cxf.apache.org/schemas/jaxws.xsd http://cxf.apache.org/transports/http/configuration http://cxf.apache.org/schemas/configuration/http-conf.xsd http://cxf.apache.org/configuration/security http://cxf.apache.org/schemas/configuration/security.xsd http://cxf.apache.org/core http://cxf.apache.org/schemas/core.xsd http://cxf.apache [...]
-    <bean class="org.springframework.beans.factory.config.PropertyPlaceholderConfigurer"/>
+    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+    xsi:schemaLocation="
+        http://www.springframework.org/schema/beans http://www.springframework.org/schema/beans/spring-beans.xsd
+        http://cxf.apache.org/transports/http/configuration http://cxf.apache.org/schemas/configuration/http-conf.xsd
+        http://cxf.apache.org/configuration/security http://cxf.apache.org/schemas/configuration/security.xsd
+        http://cxf.apache.org/core http://cxf.apache.org/schemas/core.xsd
+        ">
     <cxf:bus>
         <cxf:features>
             <cxf:logging/>
@@ -39,4 +41,4 @@
             </sec:trustManagers>
         </http:tlsClientParameters>
     </http:conduit>
-</beans>
\ No newline at end of file
+</beans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt-non-persist.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt-non-persist.xml
index e67afd5..0d5a4de 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt-non-persist.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt-non-persist.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-negative-oidc-jcache-jwt-non-persist}">
+        <httpj:engine port="${testutil.ports.oidc-negative-server-jcache-jwt-non-persist}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-negative-oidc-jcache-jwt-non-persist}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.oidc-negative-server-jcache-jwt-non-persist}</value></constructor-arg>
        <property name="useJwtFormatForAccessTokens" value="true"/>
        <property name="persistJwtEncoding" value="false"/>
    </bean>
@@ -114,7 +114,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache-jwt-non-persist}/services">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jcache-jwt-non-persist}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -145,7 +145,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache-jwt-non-persist}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jcache-jwt-non-persist}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
@@ -173,7 +173,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache-jwt-non-persist}/ui/plain">
+        address="https://localhost:${testutil.ports.oidc-negative-server-jcache-jwt-non-persist}/ui/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt.xml
index ef885db..0e55641 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache-jwt.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-negative-oidc-jcache-jwt}">
+        <httpj:engine port="${testutil.ports.oidc-negative-server-jcache-jwt}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-negative-oidc-jcache-jwt}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.oidc-negative-server-jcache-jwt}</value></constructor-arg>
        <property name="useJwtFormatForAccessTokens" value="true"/>
    </bean>
    
@@ -113,7 +113,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache-jwt}/services">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jcache-jwt}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -144,7 +144,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache-jwt}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jcache-jwt}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
@@ -171,7 +171,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache-jwt}/ui/plain">
+        address="https://localhost:${testutil.ports.oidc-negative-server-jcache-jwt}/ui/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache.xml
index cfec724..01efd30 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jcache.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-negative-oidc-jcache}">
+        <httpj:engine port="${testutil.ports.oidc-negative-server-jcache}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-negative-oidc-jcache}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.oidc-negative-server-jcache}</value></constructor-arg>
    </bean>
    
    <bean id="authorizationService" class="org.apache.cxf.rs.security.oidc.idp.OidcAuthorizationCodeService">
@@ -112,7 +112,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache}/services">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jcache}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -143,7 +143,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jcache}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
@@ -170,7 +170,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jcache}/ui/plain">
+        address="https://localhost:${testutil.ports.oidc-negative-server-jcache}/ui/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jpa.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jpa.xml
index 0519ad3..b4b1052 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jpa.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-negative-server-jpa.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-negative-oidc-jpa}">
+        <httpj:engine port="${testutil.ports.oidc-negative-server-jpa}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -75,7 +75,7 @@ under the License.
 	</bean>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JPAOAuthDataProviderImpl">
-       <constructor-arg value="${testutil.ports.jaxrs-negative-oidc-jpa}"/>
+       <constructor-arg value="${testutil.ports.oidc-negative-server-jpa}"/>
        <constructor-arg ref="entityManagerFactory"/>
    </bean>
    
@@ -125,7 +125,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jpa}/services">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jpa}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -156,7 +156,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jpa}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-negative-server-jpa}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
@@ -183,7 +183,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-negative-oidc-jpa}/ui/plain">
+        address="https://localhost:${testutil.ports.oidc-negative-server-jpa}/ui/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-dynreg.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-dynreg.xml
index c57efe3..43886f4 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-dynreg.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-dynreg.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-oidc-dynreg}">
+        <httpj:engine port="${testutil.ports.oidc-server-dynreg}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -75,7 +75,7 @@ under the License.
 
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-dynreg}/services/dynamic">
+       address="https://localhost:${testutil.ports.oidc-server-dynreg}/services/dynamic">
        <jaxrs:serviceBeans>
            <ref bean="dynRegService"/>
        </jaxrs:serviceBeans>
@@ -85,7 +85,7 @@ under the License.
    </jaxrs:server>
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-dynreg}/services/dynamicWithAt">
+       address="https://localhost:${testutil.ports.oidc-server-dynreg}/services/dynamicWithAt">
        <jaxrs:serviceBeans>
            <ref bean="dynRegServiceWithAt"/>
        </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt-non-persist.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt-non-persist.xml
index 7c99156..8ed129a 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt-non-persist.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt-non-persist.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-oidc-jcache-jwt-non-persist}">
+        <httpj:engine port="${testutil.ports.oidc-server-jcache-jwt-non-persist}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-oidc-jcache-jwt-non-persist}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.oidc-server-jcache-jwt-non-persist}</value></constructor-arg>
        <property name="useJwtFormatForAccessTokens" value="true"/>
        <property name="persistJwtEncoding" value="false"/>
    </bean>
@@ -114,7 +114,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jcache-jwt-non-persist}/services">
+       address="https://localhost:${testutil.ports.oidc-server-jcache-jwt-non-persist}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -145,7 +145,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jcache-jwt-non-persist}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-server-jcache-jwt-non-persist}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt.xml
index e8294fc..7ee1a62 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache-jwt.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-oidc-jcache-jwt}">
+        <httpj:engine port="${testutil.ports.oidc-server-jcache-jwt}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-oidc-jcache-jwt}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.oidc-server-jcache-jwt}</value></constructor-arg>
        <property name="useJwtFormatForAccessTokens" value="true"/>
    </bean>
    
@@ -113,7 +113,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jcache-jwt}/services">
+       address="https://localhost:${testutil.ports.oidc-server-jcache-jwt}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -144,7 +144,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jcache-jwt}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-server-jcache-jwt}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache.xml
index cf92fa0..4655f1b 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jcache.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-oidc-jcache}">
+        <httpj:engine port="${testutil.ports.oidc-server-jcache}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-oidc-jcache}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.oidc-server-jcache}</value></constructor-arg>
    </bean>
    
    <bean id="authorizationService" class="org.apache.cxf.rs.security.oidc.idp.OidcAuthorizationCodeService">
@@ -112,7 +112,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jcache}/services">
+       address="https://localhost:${testutil.ports.oidc-server-jcache}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -143,7 +143,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jcache}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-server-jcache}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jpa.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jpa.xml
index 135d384..cc14c61 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jpa.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/oidc-server-jpa.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-oidc-jpa}">
+        <httpj:engine port="${testutil.ports.oidc-server-jpa}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -75,7 +75,7 @@ under the License.
 	</bean>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JPAOAuthDataProviderImpl">
-       <constructor-arg value="${testutil.ports.jaxrs-oidc-jpa}"/>
+       <constructor-arg value="${testutil.ports.oidc-server-jpa}"/>
        <constructor-arg ref="entityManagerFactory"/>
    </bean>
    
@@ -125,7 +125,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jpa}/services">
+       address="https://localhost:${testutil.ports.oidc-server-jpa}/services">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="hybridService"/>
@@ -156,7 +156,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-oidc-jpa}/unsignedjwtservices">
+       address="https://localhost:${testutil.ports.oidc-server-jpa}/unsignedjwtservices">
        <jaxrs:serviceBeans>
            <ref bean="jwtAuthorizationService"/>
        </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt-non-persist.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt-non-persist.xml
index cbcfb16..1653a49 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt-non-persist.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt-non-persist.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-userinfo-jcache-jwt-non-persist}">
+        <httpj:engine port="${testutil.ports.userinfo-server-jcache-jwt-non-persist}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-userinfo-jcache-jwt-non-persist}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.userinfo-server-jcache-jwt-non-persist}</value></constructor-arg>
        <property name="useJwtFormatForAccessTokens" value="true"/>
        <property name="persistJwtEncoding" value="false"/>
    </bean>
@@ -90,7 +90,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt-non-persist}/services/oidc">
+       address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt-non-persist}/services/oidc">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="tokenService"/>
@@ -123,7 +123,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt-non-persist}/services/plain">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt-non-persist}/services/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
@@ -146,7 +146,7 @@ under the License.
 
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt-non-persist}/services/signed">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt-non-persist}/services/signed">
         <jaxrs:serviceBeans>
             <ref bean="signedUserInfoService"/>
         </jaxrs:serviceBeans>
@@ -172,7 +172,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config"
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt-non-persist}/services/encrypted">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt-non-persist}/services/encrypted">
         <jaxrs:serviceBeans>
             <ref bean="encryptedUserInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt.xml
index 452d429..ccb825d 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache-jwt.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-userinfo-jcache-jwt}">
+        <httpj:engine port="${testutil.ports.userinfo-server-jcache-jwt}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-userinfo-jcache-jwt}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.userinfo-server-jcache-jwt}</value></constructor-arg>
        <property name="useJwtFormatForAccessTokens" value="true"/>
    </bean>
    
@@ -89,7 +89,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt}/services/oidc">
+       address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt}/services/oidc">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="tokenService"/>
@@ -121,7 +121,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt}/services/plain">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt}/services/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
@@ -137,7 +137,7 @@ under the License.
 
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt}/services/signed">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt}/services/signed">
         <jaxrs:serviceBeans>
             <ref bean="signedUserInfoService"/>
         </jaxrs:serviceBeans>
@@ -163,7 +163,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config"
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache-jwt}/services/encrypted">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache-jwt}/services/encrypted">
         <jaxrs:serviceBeans>
             <ref bean="encryptedUserInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache.xml
index 2d76385..344cc2c 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jcache.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-userinfo-jcache}">
+        <httpj:engine port="${testutil.ports.userinfo-server-jcache}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -63,7 +63,7 @@ under the License.
     </httpj:engine-factory>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JCacheOAuthDataProviderImpl">
-       <constructor-arg><value>${testutil.ports.jaxrs-userinfo-jcache}</value></constructor-arg>
+       <constructor-arg><value>${testutil.ports.userinfo-server-jcache}</value></constructor-arg>
    </bean>
    
    <bean id="authorizationService" class="org.apache.cxf.rs.security.oidc.idp.OidcAuthorizationCodeService">
@@ -88,7 +88,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache}/services/oidc">
+       address="https://localhost:${testutil.ports.userinfo-server-jcache}/services/oidc">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="tokenService"/>
@@ -120,7 +120,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache}/services/plain">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache}/services/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
@@ -136,7 +136,7 @@ under the License.
 
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache}/services/signed">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache}/services/signed">
         <jaxrs:serviceBeans>
             <ref bean="signedUserInfoService"/>
         </jaxrs:serviceBeans>
@@ -162,7 +162,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config"
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jcache}/services/encrypted">
+        address="https://localhost:${testutil.ports.userinfo-server-jcache}/services/encrypted">
         <jaxrs:serviceBeans>
             <ref bean="encryptedUserInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jpa.xml b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jpa.xml
index fd386fb..ce8e204 100644
--- a/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jpa.xml
+++ b/systests/rs-security/src/test/resources/org/apache/cxf/systest/jaxrs/security/oidc/userinfo-server-jpa.xml
@@ -48,7 +48,7 @@ under the License.
     <bean id="oauthJson" class="org.apache.cxf.rs.security.oauth2.provider.OAuthJSONProvider"/>
     
     <httpj:engine-factory id="tls-config">
-        <httpj:engine port="${testutil.ports.jaxrs-userinfo-jpa}">
+        <httpj:engine port="${testutil.ports.userinfo-server-jpa}">
             <httpj:tlsServerParameters>
                 <sec:keyManagers keyPassword="password">
                     <sec:keyStore type="JKS" password="password" resource="keys/Bethal.jks"/>
@@ -75,7 +75,7 @@ under the License.
 	</bean>
     
    <bean id="oauthProvider" class="org.apache.cxf.systest.jaxrs.security.oauth2.common.JPAOAuthDataProviderImpl">
-       <constructor-arg value="${testutil.ports.jaxrs-userinfo-jpa}"/>
+       <constructor-arg value="${testutil.ports.userinfo-server-jpa}"/>
        <constructor-arg ref="entityManagerFactory"/>
    </bean>
     
@@ -101,7 +101,7 @@ under the License.
    
    <jaxrs:server 
        depends-on="tls-config" 
-       address="https://localhost:${testutil.ports.jaxrs-userinfo-jpa}/services/oidc">
+       address="https://localhost:${testutil.ports.userinfo-server-jpa}/services/oidc">
        <jaxrs:serviceBeans>
            <ref bean="authorizationService"/>
            <ref bean="tokenService"/>
@@ -133,7 +133,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jpa}/services/plain">
+        address="https://localhost:${testutil.ports.userinfo-server-jpa}/services/plain">
         <jaxrs:serviceBeans>
             <ref bean="userInfoService"/>
         </jaxrs:serviceBeans>
@@ -149,7 +149,7 @@ under the License.
 
    <jaxrs:server 
         depends-on="tls-config" 
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jpa}/services/signed">
+        address="https://localhost:${testutil.ports.userinfo-server-jpa}/services/signed">
         <jaxrs:serviceBeans>
             <ref bean="signedUserInfoService"/>
         </jaxrs:serviceBeans>
@@ -175,7 +175,7 @@ under the License.
    
    <jaxrs:server 
         depends-on="tls-config"
-        address="https://localhost:${testutil.ports.jaxrs-userinfo-jpa}/services/encrypted">
+        address="https://localhost:${testutil.ports.userinfo-server-jpa}/services/encrypted">
         <jaxrs:serviceBeans>
             <ref bean="encryptedUserInfoService"/>
         </jaxrs:serviceBeans>
diff --git a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCFlowTest.java b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCFlowTest.java
index aecda92..66b59a1 100644
--- a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCFlowTest.java
+++ b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCFlowTest.java
@@ -27,16 +27,11 @@ import java.security.cert.Certificate;
 import java.security.cert.CertificateException;
 import java.security.cert.X509Certificate;
 import java.time.Instant;
-import java.util.Arrays;
-import java.util.Collection;
 import java.util.Collections;
 
 import javax.ws.rs.core.Form;
 import javax.ws.rs.core.Response;
 
-import org.apache.cxf.Bus;
-import org.apache.cxf.BusFactory;
-import org.apache.cxf.bus.spring.SpringBusFactory;
 import org.apache.cxf.jaxrs.client.WebClient;
 import org.apache.cxf.rs.security.jose.jwa.SignatureAlgorithm;
 import org.apache.cxf.rs.security.jose.jwk.JsonWebKeys;
@@ -54,8 +49,6 @@ import org.apache.cxf.systest.jaxrs.security.SecurityTestUtil;
 import org.apache.cxf.systest.jaxrs.security.oauth2.common.OAuth2TestUtils;
 import org.apache.cxf.systest.jaxrs.security.oauth2.common.OAuth2TestUtils.AuthorizationCodeParameters;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
-import org.apache.cxf.testutil.common.AbstractBusTestServerBase;
-import org.apache.cxf.testutil.common.TestUtil;
 import org.apache.xml.security.utils.ClassLoaderUtils;
 
 import org.junit.AfterClass;
@@ -72,19 +65,19 @@ import static org.junit.Assert.assertTrue;
 /**
  * Some unit tests to test the various flows in OpenID Connect. The tests are run multiple times
  * with different OAuthDataProvider implementations:
  * a) JCACHE_PORT - JCache
  * b) JWT_JCACHE_PORT - JCache with useJwtFormatForAccessTokens enabled
  * c) JPA_PORT - JPA provider
  * d) JWT_NON_PERSIST_JCACHE_PORT-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
  */
 @RunWith(value = org.junit.runners.Parameterized.class)
 public class OIDCFlowTest extends AbstractBusClientServerTestBase {
 
-    static final String JCACHE_PORT = TestUtil.getPortNumber("jaxrs-oidc-jcache");
-    static final String JWT_JCACHE_PORT = TestUtil.getPortNumber("jaxrs-oidc-jcache-jwt");
-    static final String JPA_PORT = TestUtil.getPortNumber("jaxrs-oidc-jpa");
-    static final String JWT_NON_PERSIST_JCACHE_PORT =
-        TestUtil.getPortNumber("jaxrs-oidc-jcache-jwt-non-persist");
+    private static final SpringBusTestServer JCACHE_SERVER = new SpringBusTestServer("oidc-server-jcache");
+    private static final SpringBusTestServer JWT_JCACHE_SERVER = new SpringBusTestServer("oidc-server-jcache-jwt");
+    private static final SpringBusTestServer JPA_SERVER = new SpringBusTestServer("oidc-server-jpa");
+    private static final SpringBusTestServer JWT_NON_PERSIST_JCACHE_SERVER =
+            new SpringBusTestServer("oidc-server-jcache-jwt-non-persist");
 
     final String port;
 
@@ -94,30 +87,10 @@ public class OIDCFlowTest extends AbstractBusClientServerTestBase {
 
     @BeforeClass
     public static void startServers() throws Exception {
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCServerJCache.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCServerJCacheJWT.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCServerJPA.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCServerJCacheJWTNonPersist.class, true)
-        );
+        assertTrue("Server failed to launch", launchServer(JCACHE_SERVER));
+        assertTrue("Server failed to launch", launchServer(JWT_JCACHE_SERVER));
+        assertTrue("Server failed to launch", launchServer(JPA_SERVER));
+        assertTrue("Server failed to launch", launchServer(JWT_NON_PERSIST_JCACHE_SERVER));
     }
 
     @AfterClass
@@ -126,9 +99,12 @@ public class OIDCFlowTest extends AbstractBusClientServerTestBase {
     }
 
     @Parameters(name = "{0}")
-    public static Collection<String> data() {
-
-        return Arrays.asList(JCACHE_PORT, JWT_JCACHE_PORT, JPA_PORT, JWT_NON_PERSIST_JCACHE_PORT);
+    public static String[] data() {
+        return new String[]{
+                JCACHE_SERVER.getPort(),
+                JWT_JCACHE_SERVER.getPort(),
+                JPA_SERVER.getPort(),
+                JWT_NON_PERSIST_JCACHE_SERVER.getPort()};
     }
 
     @org.junit.Test
@@ -1005,86 +981,7 @@ public class OIDCFlowTest extends AbstractBusClientServerTestBase {
     }
 
     private boolean isAccessTokenInJWTFormat() {
-        return JWT_JCACHE_PORT.equals(port) || JWT_NON_PERSIST_JCACHE_PORT.equals(port);
-    }
-
-    //
-    // Server implementations
-    //
-
-    public static class OIDCServerJCache extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCServerJCache.class.getResource("oidc-server-jcache.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCServerJCache();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class OIDCServerJCacheJWT extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCServerJCacheJWT.class.getResource("oidc-server-jcache-jwt.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCServerJCacheJWT();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class OIDCServerJPA extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCServerJPA.class.getResource("oidc-server-jpa.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCServerJPA();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
+        return JWT_JCACHE_SERVER.equals(port) || JWT_NON_PERSIST_JCACHE_SERVER.equals(port);
     }
 
-    public static class OIDCServerJCacheJWTNonPersist extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCServerJCacheJWTNonPersist.class.getResource("oidc-server-jcache-jwt-non-persist.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCServerJCacheJWTNonPersist();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
 }
@@ -72,19 +65,19 @@ import static org.junit.Assert.assertTrue;
  * Some unit tests to test the various flows in OpenID Connect. The tests are run multiple times
  * with different OAuthDataProvider implementations:
- * a) JCACHE_PORT - JCache
- * b) JWT_JCACHE_PORT - JCache with useJwtFormatForAccessTokens enabled
- * c) JPA_PORT - JPA provider
- * d) JWT_NON_PERSIST_JCACHE_PORT-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
+ * a) JCACHE_SERVER - JCache
+ * b) JWT_JCACHE_SERVER - JCache with useJwtFormatForAccessTokens enabled
+ * c) JPA_SERVER - JPA provider
+ * d) JWT_NON_PERSIST_JCACHE_SERVER-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
  */
 @RunWith(value = org.junit.runners.Parameterized.class)
diff --git a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCNegativeTest.java b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCNegativeTest.java
index e75b314..c7ba47c 100644
--- a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCNegativeTest.java
+++ b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/OIDCNegativeTest.java
@@ -20,17 +20,12 @@ package org.apache.cxf.systest.jaxrs.security.oidc;
 
 import java.net.URL;
 import java.time.Instant;
-import java.util.Arrays;
-import java.util.Collection;
 import java.util.Collections;
 
 import javax.ws.rs.client.ResponseProcessingException;
 import javax.ws.rs.core.Form;
 import javax.ws.rs.core.Response;
 
-import org.apache.cxf.Bus;
-import org.apache.cxf.BusFactory;
-import org.apache.cxf.bus.spring.SpringBusFactory;
 import org.apache.cxf.jaxrs.client.WebClient;
 import org.apache.cxf.rs.security.jose.jws.JwsHeaders;
 import org.apache.cxf.rs.security.jose.jws.JwsJwtCompactConsumer;
@@ -45,8 +40,6 @@ import org.apache.cxf.systest.jaxrs.security.SecurityTestUtil;
 import org.apache.cxf.systest.jaxrs.security.oauth2.common.OAuth2TestUtils;
 import org.apache.cxf.systest.jaxrs.security.oauth2.common.OAuth2TestUtils.AuthorizationCodeParameters;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
-import org.apache.cxf.testutil.common.AbstractBusTestServerBase;
-import org.apache.cxf.testutil.common.TestUtil;
 
 import org.junit.AfterClass;
 import org.junit.Assert;
@@ -62,19 +55,20 @@ import static org.junit.Assert.fail;
 /**
  * Some negative tests for OpenID Connect. The tests are run multiple times with different OAuthDataProvider
  * implementations:
  * a) JCACHE_PORT - JCache
  * b) JWT_JCACHE_PORT - JCache with useJwtFormatForAccessTokens enabled
  * c) JPA_PORT - JPA provider
  * d) JWT_NON_PERSIST_JCACHE_PORT-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
  */
 @RunWith(value = org.junit.runners.Parameterized.class)
 public class OIDCNegativeTest extends AbstractBusClientServerTestBase {
 
-    static final String JCACHE_PORT = TestUtil.getPortNumber("jaxrs-negative-oidc-jcache");
-    static final String JWT_JCACHE_PORT = TestUtil.getPortNumber("jaxrs-negative-oidc-jcache-jwt");
-    static final String JPA_PORT = TestUtil.getPortNumber("jaxrs-negative-oidc-jpa");
-    static final String JWT_NON_PERSIST_JCACHE_PORT =
-        TestUtil.getPortNumber("jaxrs-negative-oidc-jcache-jwt-non-persist");
+    private static final SpringBusTestServer JCACHE_SERVER = new SpringBusTestServer("oidc-negative-server-jcache");
+    private static final SpringBusTestServer JWT_JCACHE_SERVER =
+            new SpringBusTestServer("oidc-negative-server-jcache-jwt");
+    private static final SpringBusTestServer JPA_SERVER = new SpringBusTestServer("oidc-negative-server-jpa");
+    private static final SpringBusTestServer JWT_NON_PERSIST_JCACHE_SERVER =
+            new SpringBusTestServer("oidc-negative-server-jcache-jwt-non-persist");
 
     final String port;
 
@@ -84,30 +78,10 @@ public class OIDCNegativeTest extends AbstractBusClientServerTestBase {
 
     @BeforeClass
     public static void startServers() throws Exception {
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCNegativeServerJCache.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCNegativeServerJCacheJWT.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCNegativeServerJPA.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(OIDCNegativeServerJCacheJWTNonPersist.class, true)
-        );
+        assertTrue("Server failed to launch", launchServer(JCACHE_SERVER));
+        assertTrue("Server failed to launch", launchServer(JWT_JCACHE_SERVER));
+        assertTrue("Server failed to launch", launchServer(JPA_SERVER));
+        assertTrue("Server failed to launch", launchServer(JWT_NON_PERSIST_JCACHE_SERVER));
     }
 
     @AfterClass
@@ -116,9 +90,12 @@ public class OIDCNegativeTest extends AbstractBusClientServerTestBase {
     }
 
     @Parameters(name = "{0}")
-    public static Collection<String> data() {
-
-        return Arrays.asList(JCACHE_PORT, JWT_JCACHE_PORT, JPA_PORT, JWT_NON_PERSIST_JCACHE_PORT);
+    public static String[] data() {
+        return new String[]{
+                JCACHE_SERVER.getPort(),
+                JWT_JCACHE_SERVER.getPort(),
+                JPA_SERVER.getPort(),
+                JWT_NON_PERSIST_JCACHE_SERVER.getPort()};
     }
 
     @org.junit.Test
@@ -449,83 +426,4 @@ public class OIDCNegativeTest extends AbstractBusClientServerTestBase {
         assertEquals("consumer-id", userInfo.getAudience());
     }
 
-    //
-    // Server implementations
-    //
-
-    public static class OIDCNegativeServerJCache extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCNegativeServerJCache.class.getResource("oidc-negative-server-jcache.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCNegativeServerJCache();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class OIDCNegativeServerJCacheJWT extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCNegativeServerJCacheJWT.class.getResource("oidc-negative-server-jcache-jwt.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCNegativeServerJCacheJWT();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class OIDCNegativeServerJPA extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCNegativeServerJPA.class.getResource("oidc-negative-server-jpa.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCNegativeServerJPA();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class OIDCNegativeServerJCacheJWTNonPersist extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            OIDCNegativeServerJCacheJWTNonPersist.class.getResource("oidc-negative-server-jcache-jwt-non-persist.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new OIDCNegativeServerJCacheJWTNonPersist();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
 }
@@ -62,19 +55,20 @@ import static org.junit.Assert.fail;
  * Some negative tests for OpenID Connect. The tests are run multiple times with different OAuthDataProvider
  * implementations:
- * a) JCACHE_PORT - JCache
- * b) JWT_JCACHE_PORT - JCache with useJwtFormatForAccessTokens enabled
- * c) JPA_PORT - JPA provider
- * d) JWT_NON_PERSIST_JCACHE_PORT-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
+ * a) JCACHE_SERVER - JCache
+ * b) JWT_JCACHE_SERVER - JCache with useJwtFormatForAccessTokens enabled
+ * c) JPA_SERVER - JPA provider
+ * d) JWT_NON_PERSIST_JCACHE_SERVER-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
  */
 @RunWith(value = org.junit.runners.Parameterized.class)
diff --git a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/UserInfoTest.java b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/UserInfoTest.java
index 99a841b..bc540fe 100644
--- a/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/UserInfoTest.java
+++ b/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/oidc/UserInfoTest.java
@@ -27,14 +27,9 @@ import java.security.PrivateKey;
 import java.security.cert.Certificate;
 import java.security.cert.CertificateException;
 import java.security.cert.X509Certificate;
-import java.util.Arrays;
-import java.util.Collection;
 
 import javax.ws.rs.core.Response;
 
-import org.apache.cxf.Bus;
-import org.apache.cxf.BusFactory;
-import org.apache.cxf.bus.spring.SpringBusFactory;
 import org.apache.cxf.common.classloader.ClassLoaderUtils;
 import org.apache.cxf.jaxrs.client.WebClient;
 import org.apache.cxf.rs.security.jose.jwa.SignatureAlgorithm;
@@ -48,8 +43,6 @@ import org.apache.cxf.rs.security.oidc.common.UserInfo;
 import org.apache.cxf.systest.jaxrs.security.SecurityTestUtil;
 import org.apache.cxf.systest.jaxrs.security.oauth2.common.OAuth2TestUtils;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
-import org.apache.cxf.testutil.common.AbstractBusTestServerBase;
-import org.apache.cxf.testutil.common.TestUtil;
 
 import org.junit.AfterClass;
 import org.junit.BeforeClass;
@@ -63,19 +56,19 @@ import static org.junit.Assert.assertTrue;
 /**
  * Some unit tests for the UserInfo Service in OpenId Connect. This can be used to return the User's claims given
  * an access token. The tests are run multiple times with different OAuthDataProvider implementations:
  * a) JCACHE_PORT - JCache
  * b) JWT_JCACHE_PORT - JCache with useJwtFormatForAccessTokens enabled
  * c) JPA_PORT - JPA provider
  * d) JWT_NON_PERSIST_JCACHE_PORT-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
  */
 @RunWith(value = org.junit.runners.Parameterized.class)
 public class UserInfoTest extends AbstractBusClientServerTestBase {
 
-    static final String JCACHE_PORT = TestUtil.getPortNumber("jaxrs-userinfo-jcache");
-    static final String JCACHE_JWT_PORT = TestUtil.getPortNumber("jaxrs-userinfo-jcache-jwt");
-    static final String JPA_PORT = TestUtil.getPortNumber("jaxrs-userinfo-jpa");
-    static final String JWT_NON_PERSIST_JCACHE_PORT =
-        TestUtil.getPortNumber("jaxrs-userinfo-jcache-jwt-non-persist");
+    private static final SpringBusTestServer JCACHE_SERVER = new SpringBusTestServer("userinfo-server-jcache");
+    private static final SpringBusTestServer JWT_JCACHE_SERVER = new SpringBusTestServer("userinfo-server-jcache-jwt");
+    private static final SpringBusTestServer JPA_SERVER = new SpringBusTestServer("userinfo-server-jpa");
+    private static final SpringBusTestServer JWT_NON_PERSIST_JCACHE_SERVER =
+            new SpringBusTestServer("userinfo-server-jcache-jwt-non-persist");
 
     final String port;
 
@@ -85,30 +78,10 @@ public class UserInfoTest extends AbstractBusClientServerTestBase {
 
     @BeforeClass
     public static void startServers() throws Exception {
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(UserInfoServerJCache.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(UserInfoServerJCacheJWT.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(UserInfoServerJPA.class, true)
-        );
-        assertTrue(
-                   "Server failed to launch",
-                   // run the server in the same process
-                   // set this to false to fork
-                   launchServer(UserInfoServerJCacheJWTNonPersist.class, true)
-        );
+        assertTrue("Server failed to launch", launchServer(JCACHE_SERVER));
+        assertTrue("Server failed to launch", launchServer(JWT_JCACHE_SERVER));
+        assertTrue("Server failed to launch", launchServer(JPA_SERVER));
+        assertTrue("Server failed to launch", launchServer(JWT_NON_PERSIST_JCACHE_SERVER));
     }
 
     @AfterClass
@@ -117,9 +90,12 @@ public class UserInfoTest extends AbstractBusClientServerTestBase {
     }
 
     @Parameters(name = "{0}")
-    public static Collection<String> data() {
-
-        return Arrays.asList(JCACHE_PORT, JCACHE_JWT_PORT, JPA_PORT, JWT_NON_PERSIST_JCACHE_PORT);
+    public static String[] data() {
+        return new String[]{
+                JCACHE_SERVER.getPort(),
+                JWT_JCACHE_SERVER.getPort(),
+                JPA_SERVER.getPort(),
+                JWT_NON_PERSIST_JCACHE_SERVER.getPort()};
     }
 
     @org.junit.Test
@@ -314,83 +290,4 @@ public class UserInfoTest extends AbstractBusClientServerTestBase {
                                                           SignatureAlgorithm.RS256));
     }
 
-    //
-    // Server implementations
-    //
-
-    public static class UserInfoServerJCache extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            UserInfoServerJCache.class.getResource("userinfo-server-jcache.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new UserInfoServerJCache();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class UserInfoServerJCacheJWT extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            UserInfoServerJCacheJWT.class.getResource("userinfo-server-jcache-jwt.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new UserInfoServerJCacheJWT();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class UserInfoServerJPA extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            UserInfoServerJPA.class.getResource("userinfo-server-jpa.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new UserInfoServerJPA();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
-
-    public static class UserInfoServerJCacheJWTNonPersist extends AbstractBusTestServerBase {
-        private static final URL SERVER_CONFIG_FILE =
-            UserInfoServerJCacheJWTNonPersist.class.getResource("userinfo-server-jcache-jwt-non-persist.xml");
-
-        protected void run() {
-            SpringBusFactory bf = new SpringBusFactory();
-            Bus springBus = bf.createBus(SERVER_CONFIG_FILE);
-            BusFactory.setDefaultBus(springBus);
-            setBus(springBus);
-
-            try {
-                new UserInfoServerJCacheJWTNonPersist();
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }
-
-    }
 }
@@ -63,19 +56,19 @@ import static org.junit.Assert.assertTrue;
  * Some unit tests for the UserInfo Service in OpenId Connect. This can be used to return the User's claims given
  * an access token. The tests are run multiple times with different OAuthDataProvider implementations:
- * a) JCACHE_PORT - JCache
- * b) JWT_JCACHE_PORT - JCache with useJwtFormatForAccessTokens enabled
- * c) JPA_PORT - JPA provider
- * d) JWT_NON_PERSIST_JCACHE_PORT-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
+ * a) JCACHE_SERVER - JCache
+ * b) JWT_JCACHE_SERVER - JCache with useJwtFormatForAccessTokens enabled
+ * c) JPA_SERVER - JPA provider
+ * d) JWT_NON_PERSIST_JCACHE_SERVER-  JCache with useJwtFormatForAccessTokens + !persistJwtEncoding
  */
 @RunWith(value = org.junit.runners.Parameterized.class)